fetch_schema()

Fetch the schema of a specified artefact from an SDMX registry.

Usage

fetch_schema(
    base_url,
    artefact_id,
    context,
)

Parameters

base_url: str

The base URL of the FMR.

artefact_id: str

The identifier of the artefact, typically in the format "agency:id(version)".

context: Literal["dataflow", "datastructure", "provisionagreement"]
The context of the artefact to fetch.

Returns

Schema
The fetched schema object.