parse_mapping_template_wb()

Read an Excel mapping template and return all sheets as DataFrames.

Usage

parse_mapping_template_wb(path)

Parameters

path: str | Path
Path to the Excel file.

Returns

dict[str, pd.DataFrame]
A dictionary where keys are sheet names and values are DataFrames.

Raises

FileNotFoundError

If the provided file path does not exist.

ValueError

If the file is not an Excel file (.xlsx or .xls).

RuntimeError
If reading the Excel file fails.