validate_no_missing_values()

Validate that there are no missing values in mandatory columns.

Usage

validate_no_missing_values(
    df,
    mandatory_columns,
    max_errors=1000,
)

Parameters

df: pd.DataFrame

The DataFrame to validate.

mandatory_columns: list[str]

List of mandatory column names to check.

max_errors: int = 1000
Maximum number of rows with missing values to include in the error message. Defaults to 1000.

Raises

ValueError
If missing values are found in any mandatory column, reporting the count and the offending rows (up to max_errors).