build_implicit_component_map()
Build a pysdmx ImplicitComponentMap for implicit mapping rules.
Usage
build_implicit_component_map(
source,
target,
)Parameters
source: str-
The ID of the source component in the structure map.
target: str- The ID of the target component in the structure map.
Returns
ImplicitComponentMap- A pysdmx ImplicitComponentMap object.
Raises
ValueError-
If
sourceortargetis empty.
Examples
>>> mapping = build_implicit_component_map("FREQ", "FREQUENCY")
>>> isinstance(mapping, ImplicitComponentMap)
True