kd_validate_dataset_local()
Validate a single DataFrame for SDMX compliance.
Usage
kd_validate_dataset_local(
df,
schema=None,
valid=None,
)Wrapper that calls validate_dataset_local to obtain a DataFrame of errors, then logs messages and returns a tuple of (success, errors).
Parameters
df: pd.DataFrame-
The DataFrame to be validated.
schema=None-
The schema object containing validation information (optional if
validis provided). valid=None- Precomputed validation information (optional).
Returns
bool-
A tuple where the first element is True if the dataset passed
dict-
validation (no errors) and False otherwise, and the second element
tuple[bool, dict]-
is an empty dict on success or a dict with key
mapping to the list of error messages.ValidationReport